<html lang="en"><head>
<title>IceBear help</title>
<link rel="stylesheet" href="/help/help.css" />
<script type="text/javascript" src="/js/prototype1_7_2.js"></script>
</head><body id="frames">
<iframe name="navframe" id="navframe" src="/help/nav.php"></iframe>
<iframe name="helpframe" id="helpframe" src="/help/basics/index.php"></iframe>
<script type="text/javascript">
document.getElementById("helpframe").addEventListener("load",function(){
//	alert(document.getElementById("helpframe").contentWindow.location.href);
});
</script>
</body></html>